Change writetrim to trimwrite
[fio.git] / backend.c
index e8599eef0edffaf3dd1fe9cbee29ab588659f0db..25479b49c9c9f1a82b7d39bec3cb11d5a816327b 100644 (file)
--- a/backend.c
+++ b/backend.c
@@ -744,9 +744,9 @@ static uint64_t do_io(struct thread_data *td)
           (td_write(td) && td->o.verify_backlog))
                total_bytes += td->o.size;
 
/* In writetrim mode, each byte is trimmed and then written, so
         * allow total_bytes to be twice as big */
-       if (td_writetrim(td))
+       if (td_trimwrite(td))
                total_bytes += td->total_io_size;
 
        while ((td->o.read_iolog_file && !flist_empty(&td->io_log_list)) ||
@@ -744,9 +744,9 @@ static uint64_t do_io(struct thread_data *td)
                total_bytes += td->o.size;
 
-       /* In writetrim mode, each byte is trimmed and then written, so
+       /* In trimwrite mode, each byte is trimmed and then written, so
         * allow total_bytes to be twice as big */